@@ -31,7 +31,6 @@
 
 require_once("guiconfig.inc");
 require_once("interfaces.inc");
-require_once("services.inc");
 require_once("plugins.inc.d/dhcpd.inc");
 
 function adjust_utc($dt)
@@ -315,9 +314,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'GET') {
     }
 } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
     if (!empty($_POST['deleteip']) && is_ipaddr($_POST['deleteip'])) {
-        // delete dhcp lease
-        /* Stop DHCPD */
-        killbyname("dhcpd");
+        killbypid('/var/dhcpd/var/run/dhcpdv6.pid', 'TERM', true);
         $fin = @fopen($leasesfile, "r");
         $fout = @fopen($leasesfile.".new", "w");
         if ($fin) {
